Delegate

Trait Delegate 

pub trait Delegate: MergeDelegate<Id = Self::Id, Address = Self::Address> + ReconnectDelegate<Id = Self::Id, Address = Self::Address> {
    type Id: Id;
    type Address: CheapClone + Send + Sync + 'static;
}
Delegate is the trait that clients must implement if they want to hook into the gossip layer of Serf. All the methods must be thread-safe, as they can and generally will be called concurrently.

Required Associated Types

type Id: Id

The id type of the delegate

type Address: CheapClone + Send + Sync + 'static

The address type of the delegate

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I, A, M, R> Delegate for CompositeDelegate<I, A, M, R>
where I: Id + Send + Sync + 'static, A: CheapClone + Send + Sync + 'static, M: MergeDelegate<Id = I, Address = A>, R: ReconnectDelegate<Id = I, Address = A>,

Source

type Id = I

Source

type Address = A