pub struct EventProducer<T, D>{ /* private fields */ }Expand description
The producer of the Serf events.
Implementations
Sourceimpl<T, D> EventProducer<T, D>
impl<T, D> EventProducer<T, D>
Sourcepub fn bounded(size: usize) -> (Self, EventSubscriber<T, D>)
pub fn bounded(size: usize) -> (Self, EventSubscriber<T, D>)
Creates a bounded producer and subscriber.
The created subscriber has space to hold at most cap events at a time. Users must actively consume the events from the subscriber to prevent the producer from blocking.
Sourcepub fn unbounded() -> (Self, EventSubscriber<T, D>)
pub fn unbounded() -> (Self, EventSubscriber<T, D>)
Creates an unbounded producer and subscriber.
The created subscriber has no limit on the number of events it can hold.