pub struct MemberEvent<I, A> { /* private fields */ }Expand description
MemberEvent is the struct used for member related events Because Serf coalesces events, an event may contain multiple members.
Implementations
Sourceimpl<I, A> MemberEvent<I, A>
impl<I, A> MemberEvent<I, A>